liblisa-synth 0.3.0

A tool for automated discovery and analysis of the ISA of a CPU.
docs.rs failed to build liblisa-synth-0.3.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: liblisa-synth-0.1.0

This library contains the default synthesis implementation for libLISA. It can be invoked as follows (for x64):

# fn wrap(encoding: liblisa::encoding::Encoding<liblisa::arch::x64::X64Arch, ()>) {
// let encoding = ...; // see the `liblisa-enc` crate
let semantics = liblisa_x64_observer::with_oracle(|mut oracle| {
    liblisa_synth::synthesize_semantics(encoding, &mut oracle)
});

println!("{semantics}");
# }